spacetimedb_expr_2::ty

Struct TyId

pub struct TyId(/* private fields */);
When type checking a super::expr::RelExpr, types are stored in a typing context TyCtx. It will then hold references, in the form of TyIds, to the types defined in the TyCtx.

Implementations

Source

impl TyId

pub const BOOL: Self = _

A static type id for Bool

pub const I8: Self = _

A static type id for I8

pub const U8: Self = _

A static type id for U8

pub const I16: Self = _

A static type id for I16

pub const U16: Self = _

A static type id for U16

pub const I32: Self = _

A static type id for I32

pub const U32: Self = _

A static type id for U32

pub const I64: Self = _

A static type id for I64

pub const U64: Self = _

A static type id for U64

pub const I128: Self = _

A static type id for I128

pub const U128: Self = _

A static type id for U128

pub const I256: Self = _

A static type id for I256

pub const U256: Self = _

A static type id for U256

pub const F32: Self = _

A static type id for F32

pub const F64: Self = _

A static type id for F64

pub const STR: Self = _

A static type id for String

pub const BYTES: Self = _

A static type id for a byte array

pub const IDENT: Self = _

A static type id for AlgebraicType::identity()