pub struct TyId(/* private fields */);Expand description
When type checking a super::expr::RelExpr, types are stored in a typing context TyCtx. It will then hold references, in the form of TyIds, to the types defined in the TyCtx.
Implementations